==> SimplyDualWielding-4.5.0%2B1.21.4-Fabric-sources.jar: eva/dualwielding/util/OffhandMine.java <==
package eva.dualwielding.util;

import com.natamus.collective.fabric.callbacks.CollectivePlayerEvents;
import eva.dualwielding.DualWieldingMain;
import eva.dualwielding.access.BlockAccess;
import java.util.Objects;
import net.minecraft.class_1268;
import net.minecraft.class_1292;
import net.minecraft.class_1294;
import net.minecraft.class_1324;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1893;
import net.minecraft.class_1922;
import net.minecraft.class_1934;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2694;
import net.minecraft.class_3486;
import net.minecraft.class_5134;
import net.minecraft.class_7924;
import net.minecraft.class_9274;
import net.minecraft.class_9285;
import net.minecraft.class_9334;

public class OffhandMine {

    public static class_1324 offEfficiency;
    public static class_1324 offSubSpeed;
    public static class_1324 offBreakSpeed;
    private static class_1799 offhandStack;

    //manage attributes
    public static void setOffAttributes(class_1657 playerEntity) {
        if ((offhandStack == null && playerEntity.method_6079() != null ) || offhandStack != null && !offhandStack.equals(playerEntity.method_6079())) {
            offhandStack = playerEntity.method_6079();
            offEfficiency = new class_1324(class_5134.field_51581, eff -> playerEntity.method_5996(class_5134.field_51581));
            offSubSpeed = new class_1324(class_5134.field_51576, sub -> playerEntity.method_5996(class_5134.field_51576));
            offBreakSpeed = new class_1324(class_5134.field_49076, bs -> playerEntity.method_5996(class_5134.field_49076));
            offEfficiency.method_6192(playerEntity.method_45326(class_5134.field_51581));
            offSubSpeed.method_6192(playerEntity.method_45326(class_5134.field_51576));
            offBreakSpeed.method_6192(playerEntity.method_45326(class_5134.field_49076));
            class_1799 mainStack = playerEntity.method_6047();
            if (!mainStack.method_7960()) {
                if (mainStack.method_7909().method_57347().method_57832(class_9334.field_49636)) {
                    class_9285 component = mainStack.method_57353().method_57829(class_9334.field_49636);
                    if (component != null) {
                        component.comp_2393().forEach((mod) -> {
                            if (offEfficiency.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51581)
                                offEfficiency.method_6202(mod.comp_2396());
                        });
                        component.comp_2393().forEach((mod) -> {
                            if (offSubSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51576)
                                offSubSpeed.method_6202(mod.comp_2396());
                        });
                        component.comp_2393().forEach((mod) -> {
                            if (offBreakSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_49076)
                                offBreakSpeed.method_6202(mod.comp_2396());
                        });
                    }
                }
            }
            class_1799 offStack = playerEntity.method_6079();
            if (!offStack.method_7960()) {
                if (offStack.method_7909().method_57347().method_57832(class_9334.field_49636)) {
                    class_9285 component2 = offStack.method_57353().method_57829(class_9334.field_49636);
                    if (component2 != null) {
                        component2.comp_2393().forEach((mod) -> {
                            if (!offEfficiency.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51581)
                                offEfficiency.method_26837(mod.comp_2396());
                        });
                        component2.comp_2393().forEach((mod) -> {
                            if (!offSubSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51576)
                                offSubSpeed.method_26837(mod.comp_2396());
                        });
                        component2.comp_2393().forEach((mod) -> {
                            if (!offBreakSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_49076)
                                offBreakSpeed.method_26837(mod.comp_2396());
                        });
                    }
                }
            }
            if (OffhandAttack.offSpeed == null) OffhandAttack.setOffAttributes(playerEntity);
        }
    }

    public static float getBlockBreakingSpeed(class_2680 block, class_1657 pE) {
        setOffAttributes(pE);
        float f = pE.method_5998(class_1268.field_5810).method_7924(block);

        if (f > 1.0F) {
            f += (float) offEfficiency.method_6194();
            int p = class_1890.method_8225(pE.method_37908().method_30349().method_30530(class_7924.field_41265).method_46747(class_1893.field_9131),pE.method_6079());
            if (p > 0) f += p * p + 1;
        }

        if (class_1292.method_5576(pE)) {
            f *= 1.0F + (class_1292.method_5575(pE) + 1) * 0.2F;
        }

        if (pE.method_6059(class_1294.field_5901)) {
            float var10000;
            switch (Objects.requireNonNull(pE.method_6112(class_1294.field_5901)).method_5578()) {
                case 0 -> var10000 = 0.3F;
                case 1 -> var10000 = 0.09F;
                case 2 -> var10000 = 0.0027F;
                default -> var10000 = 8.1E-4F;
            }

            float g = var10000;
            f *= g;
        }

        f *= (float) offBreakSpeed.method_6194();
        if (pE.method_5777(class_3486.field_15517)) {
            f *= (float) offSubSpeed.method_6194();
        }

        if (!pE.method_24828()) {
            f /= 5.0F;
        }

        return f;
    }

    public static boolean isOffhandBlockBreakingRestricted(class_1937 world, class_2338 pos, class_1934 gameMode, class_1657 pE) {
        if (!gameMode.method_8387()) {
            return false;
        } else if (gameMode == class_1934.field_9219) {
            return true;
        } else if (pE.method_7294()) {
            return false;
        } else {
            return !pE.method_6079().method_57373(new class_2694(world, pos, false));
        }
    }

    public static float calcBlockBreakingDelta(class_2680 blockState, class_1657 player, class_1922 world, class_2338 pos) {
        float g = 0;
        float f = ((BlockAccess) blockState).dualWielding$calcBlockBreakingDelta(player,world, pos);
        if (DualWieldingMain.collectiveLoaded) g = CollectivePlayerEvents.ON_PLAYER_DIG_SPEED_CALC.invoker().onDigSpeedCalc((class_1937) world, player, f, blockState);
        f = g > 0 ? g : f;
        return f;
    }
}

==> SimplyDualWielding-5.0.0%2B1.21.5-Fabric-sources.jar: eva/dualwielding/util/OffhandMine.java <==
package eva.dualwielding.util;

import com.natamus.collective.fabric.callbacks.CollectivePlayerEvents;
import eva.dualwielding.DualWieldingMain;
import eva.dualwielding.access.BlockAccess;
import java.util.Objects;
import net.minecraft.class_1292;
import net.minecraft.class_1294;
import net.minecraft.class_1324;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1893;
import net.minecraft.class_1922;
import net.minecraft.class_1934;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2694;
import net.minecraft.class_3486;
import net.minecraft.class_5134;
import net.minecraft.class_7924;
import net.minecraft.class_9274;
import net.minecraft.class_9285;
import net.minecraft.class_9334;

public class OffhandMine {

    public static class_1324 offEfficiency;
    public static class_1324 offSubSpeed;
    public static class_1324 offBreakSpeed;
    private static class_1799 offhandStack;

    //manage attributes
    public static void setOffAttributes(class_1657 playerEntity) {
        if (offhandStack == null || !offhandStack.equals(playerEntity.method_6079())) {
            offhandStack = playerEntity.method_6079();
            offEfficiency = new class_1324(class_5134.field_51581, eff -> playerEntity.method_5996(class_5134.field_51581));
            offSubSpeed = new class_1324(class_5134.field_51576, sub -> playerEntity.method_5996(class_5134.field_51576));
            offBreakSpeed = new class_1324(class_5134.field_49076, bs -> playerEntity.method_5996(class_5134.field_49076));
            offEfficiency.method_6192(playerEntity.method_45326(class_5134.field_51581));
            offSubSpeed.method_6192(playerEntity.method_45326(class_5134.field_51576));
            offBreakSpeed.method_6192(playerEntity.method_45326(class_5134.field_49076));
            class_1799 mainStack = playerEntity.method_6047();
            if (!mainStack.method_7960()) {
                if (mainStack.method_57353().method_57832(class_9334.field_49636)) {
                    class_9285 component = mainStack.method_57353().method_58694(class_9334.field_49636);
                    if (component != null) {
                        component.comp_2393().forEach((mod) -> {
                            if (offEfficiency.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51581)
                                offEfficiency.method_6202(mod.comp_2396());
                        });
                        component.comp_2393().forEach((mod) -> {
                            if (offSubSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51576)
                                offSubSpeed.method_6202(mod.comp_2396());
                        });
                        component.comp_2393().forEach((mod) -> {
                            if (offBreakSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_49076)
                                offBreakSpeed.method_6202(mod.comp_2396());
                        });
                    }
                }
            }
            if (!offhandStack.method_7960()) {
                if (offhandStack.method_57353().method_57832(class_9334.field_49636)) {
                    class_9285 component2 = offhandStack.method_57353().method_58694(class_9334.field_49636);
                    if (component2 != null) {
                        component2.comp_2393().forEach((mod) -> {
                            if (!offEfficiency.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51581)
                                offEfficiency.method_26837(mod.comp_2396());
                        });
                        component2.comp_2393().forEach((mod) -> {
                            if (!offSubSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_51576)
                                offSubSpeed.method_26837(mod.comp_2396());
                        });
                        component2.comp_2393().forEach((mod) -> {
                            if (!offBreakSpeed.method_6196(mod.comp_2396().comp_2447()) && mod.comp_2397() == class_9274.field_49217
                                    && mod.comp_2395() == class_5134.field_49076)
                                offBreakSpeed.method_26837(mod.comp_2396());
                        });
                    }
                }
            }
            if (OffhandAttack.offSpeed == null) OffhandAttack.setOffAttributes(playerEntity);
        }
    }

    public static float getBlockBreakingSpeed(class_2680 block, class_1657 pE) {
        setOffAttributes(pE);
        float f = pE.method_6079().method_7924(block);

        if (f > 1.0F) {
            f += (float) offEfficiency.method_6194();
            int p = class_1890.method_8225(pE.method_56673().method_30530(class_7924.field_41265).method_46747(class_1893.field_9131), pE.method_6079());
            if (p > 0) f += p * p + 1;
        }

        if (class_1292.method_5576(pE)) {
            f *= 1.0F + (class_1292.method_5575(pE) + 1) * 0.2F;
        }

        if (pE.method_6059(class_1294.field_5901)) {
            float g = switch (Objects.requireNonNull(pE.method_6112(class_1294.field_5901)).method_5578()) {
                case 0 -> 0.3F;
                case 1 -> 0.09F;
                case 2 -> 0.0027F;
                default -> 8.1E-4F;
            };
            f *= g;
        }

        f *= (float) offBreakSpeed.method_6194();
        if (pE.method_5777(class_3486.field_15517)) {
            f *= (float) offSubSpeed.method_6194();
        }

        if (!pE.method_24828()) {
            f /= 5.0F;
        }

        return f;
    }

    public static boolean isOffhandBlockBreakingRestricted(class_1937 level, class_2338 pos, class_1934 gameType, class_1657 player) {
        if (!gameType.method_8387()) {
            return false;
        } else if (gameType == class_1934.field_9219) {
            return true;
        } else if (player.method_7294()) {
            return false;
        } else {
            return !player.method_6079().method_57373(new class_2694(level, pos, false));
        }
    }

    public static float calcBlockBreakingDelta(net.minecraft.class_2680 blockState, class_1657 player, class_1922 world, class_2338 pos) {
        float g = 0;
        float f = ((BlockAccess) blockState).dualWielding$calcBlockBreakingDelta(player,world, pos);
        if (DualWieldingMain.collectiveLoaded) g = CollectivePlayerEvents.ON_PLAYER_DIG_SPEED_CALC.invoker().onDigSpeedCalc((class_1937) world, player, f, blockState);
        f = g > 0 ? g : f;
        return f;
    }
}
